
class cos():
    def __init__(self):
        self.x = 2
        self.y = 4
    def dodawanie(self):
        return(self.x + self.y)

class author():
    def author(self):
        return("author olekps")